---
title: <span class="badge object-type-scalar"></span> Meter
---
# <span class="badge object-type-scalar"></span> Meter

Length: meter (m)

## Definition

```python
# Length: meter (m)
Meter: typing.Literal["lengthm"] = "lengthm"
```
